# Conditionally build with a minimal dependency set
%bcond_with jp_minimal

Name:           freemarker
Version:        2.3.30
Release:        %mkrel 1
Group:          Development/Java
Summary:        The Apache FreeMarker Template Engine
License:        ASL 2.0
URL:            https://freemarker.apache.org/
Source0:        https://github.com/apache/freemarker/archive/v%{version}/%{name}-%{version}.tar.gz

# Remove JSP 2.0 API usage
Patch1:         jsp-api.patch
# Compile only the classes compatible with the version of jython
Patch2:         jython-compatibility.patch
# illegal character in the javadoc comment
Patch3:         fix-javadoc-encoding.patch
# Disable JRebel integration, it is not free software and not in Fedora
Patch5:         no-javarebel.patch
# enable jdom extension
Patch6:         enable-jdom.patch
# Fix compatibility with javacc 7
Patch7:         javacc-7.patch
Patch8:		freemarker-2.3.30-use-jakarta-el.patch
BuildArch:      noarch

BuildRequires: java-1.8.0-openjdk-devel
BuildRequires: ant
BuildRequires: apache-parent
BuildRequires: apache-commons-logging
BuildRequires: aqute-bnd
BuildRequires: hamcrest
BuildRequires: ivy-local
BuildRequires: glassfish-jsp-api
BuildRequires: glassfish-servlet-api
BuildRequires: javacc >= 7.0
BuildRequires: jaxen >= 1.1
BuildRequires: jcl-over-slf4j
BuildRequires: jdom >= 1.0
BuildRequires: junit
BuildRequires: log4j-over-slf4j
BuildRequires: slf4j
BuildRequires: xalan-j2 >= 2.7.0

BuildRequires: locales

%if %{without jp_minimal}
BuildRequires: dom4j
BuildRequires: saxpath
BuildRequires: jython
BuildRequires: rhino >= 1.6
%endif

%description
Apache FreeMarker is a template engine: a Java library to generate text output
(HTML web pages, e-mails, configuration files, source code, etc.) based on
templates and changing data. Templates are written in the FreeMarker Template
Language (FTL), which is a simple, specialized language (not a full-blown
programming language like PHP).

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q

find -type f -name "*.jar" -delete
find -type f -name "*.class" -delete

%patch1
%patch2
%patch3
%patch5
%patch6
%patch7 -p1
%patch8 -p1

# Use system ivy settings
rm ivysettings.xml

# Correct classpath for Javadoc generation
sed -i 's/cachepath conf="IDE"/cachepath conf="javadoc"/' build.xml
sed -i '/conf name="IDE"/i<conf name="javadoc" extends="build.jython2.5,build.jsp2.1" />' ivy.xml

# Disable Java 8 javadoc linting
sed -i '/<javadoc/a\ additionalparam="-Xdoclint:none" encoding="UTF-8"' build.xml

# Drop unnecessary dep on avalon
sed -i -e '/avalon-logkit/d' ivy.xml
rm src/main/java/freemarker/log/_AvalonLoggerFactory.java

%if %{with jp_minimal}
# Drop dep on optional extra deps for minimal build
sed -i -e '/"rhino"/d' -e '/"jython"/d' ivy.xml
rm -rf src/main/java/freemarker/ext/{rhino,jython,ant}
rm src/main/java/freemarker/template/utility/JythonRuntime.java
# Drop dep on additional xml backends for minimal build
sed -i -e '/dom4j/d' -e '/saxpath/d' ivy.xml
rm src/main/java/freemarker/ext/xml/_Dom4jNavigator.java
%endif

# Don't import all the logger implementations in the OSGi metadata
sed -i -e '/^Import-Package/s/:/: !org.apache.log4j, /' osgi.bnd

%mvn_file org.%{name}:%{name} %{name}

%build
export LANG=C.UTF-8
export JAVA_HOME=%{_jvmdir}/java-1.8.0
ant -Divy.mode=local -Ddeps.available=true javacc jar javadoc maven-pom

%install
export LANG=C.UTF-8
%mvn_artifact build/pom.xml build/%{name}.jar
%mvn_install -J build/api

%files -f .mfiles
%doc README.md RELEASE-NOTES
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE




%changelog
* Sat Jan 23 2021 neoclust <neoclust> 2.3.30-1.mga8
+ Revision: 1672925
- Fix build with jakarta-el
+ daviddavid <daviddavid>
- Update to latest upstream release 2.3.30
- Fixing to Java 8 due to requirement for Java 8 boot classpath; this should
  be ported to use the compiler release flag in the future

* Sat Feb 15 2020 umeabot <umeabot> 2.3.28-4.mga8
+ Revision: 1527751
- Mageia 8 Mass Rebuild

* Wed Jul 24 2019 daviddavid <daviddavid> 2.3.28-3.mga8
+ Revision: 1423768
- Allow conditionally building with a reduced dependency set

* Thu Sep 20 2018 umeabot <umeabot> 2.3.28-2.mga7
+ Revision: 1278377
- Mageia 7 Mass Rebuild

* Fri Aug 24 2018 daviddavid <daviddavid> 2.3.28-1.mga7
+ Revision: 1253701
- Update to latest upstream release 2.3.28
- Drop unnecessary dep on saxpath and avalon

* Sun Apr 22 2018 daviddavid <daviddavid> 2.3.27-1.mga7
+ Revision: 1221054
- new version: 2.3.27 (sync with fc29):
  * Update to latest release, project moved to the Apache Foundation
  * Drop unnecessary dep on findbugs
  * Build against glassfish instead of jboss

* Thu Oct 05 2017 daviddavid <daviddavid> 2.3.23-4.mga7
+ Revision: 1168923
- Fix compatibility with javacc 7

* Wed Mar 02 2016 neoclust <neoclust> 2.3.23-3.mga6
+ Revision: 981896
- Second rebuild of the java stack

* Sun Feb 28 2016 neoclust <neoclust> 2.3.23-2.mga6
+ Revision: 980489
- New version
- First rebuild of the java stack

* Tue Feb 09 2016 umeabot <umeabot> 2.3.19-10.mga6
+ Revision: 951918
- Mageia 6 Mass Rebuild

* Sun Jan 11 2015 pterjan <pterjan> 2.3.19-9.mga5
+ Revision: 809888
- Sync with Fedora 21

* Wed Oct 15 2014 umeabot <umeabot> 2.3.19-8.mga5
+ Revision: 740292
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.3.19-7.mga5
+ Revision: 679342
- Mageia 5 Mass Rebuild

* Mon Jan 06 2014 dmorgan <dmorgan> 2.3.19-6.mga4
+ Revision: 565148
- Fix source for pom file

* Thu Jan 02 2014 dmorgan <dmorgan> 2.3.19-5.mga4
+ Revision: 564000
- Adapt to tomcat 7

* Sat Oct 19 2013 umeabot <umeabot> 2.3.19-4.mga4
+ Revision: 530958
- Mageia 4 Mass Rebuild

* Tue Jul 30 2013 joequant <joequant> 2.3.19-3.mga4
+ Revision: 461159
- remove java-nodeps from buildrequires

* Fri Jan 11 2013 umeabot <umeabot> 2.3.19-2.mga3
+ Revision: 350917
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 10 2012 dmorgan <dmorgan> 2.3.19-1.mga3
+ Revision: 291749
- New version

* Wed Oct 19 2011 gil <gil> 2.3.16-1.mga2
+ Revision: 156652
- update to 2.3.16
- edit depmap for backward compatibility
- added maven2 pom

* Thu Apr 28 2011 dmorgan <dmorgan> 2.3.13-13.mga1
+ Revision: 92443
- Rebuild after bootstrapping
- imported package freemarker


* Wed Mar 16 2011 Omair Majid <omajid@redhat.com> - 2.3.13-12
- Drop build dependency on struts
- Remove buildroot cleaning and definition
- Remove versioned jars
- Remove dependency of javadoc subpackage on main package

* Mon Feb 28 2011 Omair Majid <omajid@redhat.com> - 2.3.13-12
- Remove dependency on tomcat5

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.13-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Sep 13 2010 Alexander Kurtakov <akurtako@redhat.com> 2.3.13-10
- Adapt to tomcat6-el jar rename.

* Mon Sep 13 2010 Alexander Kurtakov <akurtako@redhat.com> 2.3.13-9
- Add tomcat6-libs BR.
- Use global instead of define.

* Sat Feb 27 2010 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-8
- fix build patch for use of the javacc 5.0
- patch for encoding
- disable brp-java-repack-jars

* Sat Feb 27 2010 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-7
- patch for logging
- remove name from the summary

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.13-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Sep 01 2008 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-4
- Redundant dependency upon xerces-j2 is removed (#456276#c6)
- The dos2unix package is added as the build requirements
- The ant-nodeps build-time requirement is added

* Wed Aug 20 2008 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-3
- The downloads.sourceforge.net host is used in the source URL
- %%{__install} and %%{__cp} are used everywhere
- %%defattr(-,root,root,-) is used everywhere

* Fri Aug 14 2008 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-2
- Appropriate values of Group Tags are chosen from the official list
- Versions of java-devel & jpackage-utils are corrected
- Name of dir for javadoc is changed
- Manual is removed due to http://freemarker.org/docs/index.html

* Fri Jun 06 2008 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-1
- Initial version
